/*----------------------------------------------------------------

                   SASEXFSD Macro Library

        Name: fsd_filetransurl.sas  
 Description: This macro reads FSD data by FILENAME trans URL access.
              The SASEXFSD Interface Engine                   
   Title: Reading FactSet Data by URL Access on FILENAME Statement.
 Product: SAS/ETS Software                                    
    Keys: FACTSET data extraction, XML FACTSET Data                             
   Procs: SASEXFSD
   Notes: This is an uncompiled macro, used by SASEXFSD to build     
          a FactSet Query for web access. A FactSet Research Systems
          Username and Password are required:

          filename trans url
             'https://datadirect.factset.com/services/FastFetch?
                 factlet=extractcompanydata&
                    format=sml&ids=ibm,fds,goog&
                       items=p%20price,p%20volume&
                          dates=20100615:20110315:m&
                             orientation=eti'                
          user='SAS_NC_255319_SERVICES'
          pass='#Yj81[G*QJrS';

          s0859920, 04may2012, saskff changed format=xml to format=sml
          s0923282, 30nov2012, saskff pulled for 13.1 copy at v940m1
          s0852317, 01Feb2012, saskff add function= and dbsource=
                               libname options for ExtractEconData
          s0852300, 22Mar2013, saskff add cutoff=, matchDate= 
                               libname options for ExtractBenchmarkDetail
          s1148719, 05Feb2015, saskff add proxy=, connect=
                               libname options for all factlets.
 Support: saskff
 Parameters: 

  fact       - the FactSet stored process (factlet) you want to invoke
  form       - format, so far we use XML only 
  tick       - BY groups or ids/KEYS that the time series are organized
               such as Ticker, Country, etc.
               Also referred to as Entities
  itms       - Items or Time Series Names you are selecting
  range      - Range of dates, or DateString that gives the range and the frequency
  
  meta       - Orientation of metadata; Organization of the FactSet Service response
               ETI is the most common: entity, time, items
  user       - FactSet Account Username
  pass       - FactSet Account Password

Additional allowed parameters follow:
  freq       - period, frequency, interval or type of time series data to be read
               This is not always the same as the reporting interval, 
               according to Margo at FactSet.
  start      - string or numeric start date, i.e. 20101119 is a numeric date
  end        - string or numeric end date, i.e. 20101126 is a numeric date
  flag       - set to 1 if start is a relative date, and therefore a string
             - set to 0 (default) if start is a numeric date
             - stored in fsdlib->relative_dates_flag
  FQLfreq    - used in conjunction with start, end, this is different from period
  FQLflag    - Y or N (default) to indicate FQL dates instead of screening dates
  ison       - ison codes for current constituents
  isonParams - ison codes that use parameters
  ofdb       - open factset database to extract from
  datesOnly  - Y or N (default) get only the dates in the OFDB
  universe   - used by extractcompanydata and extractformulahistory
  universegroup - used by extractdatasnapshot
  cal        - calendar setting that replicates the PSETCAL function
  screen     - filename for the ExtractScreenUniverse
  name       - Y means yes, show the names for the cusips in the screen universe
             - N is default for no, don't show the names in the screen universe output
  curr       - totally optional, so may not exist, currency for ExtractFormulaHistory
  conv       - totally optional, so may not exist, default is NONE, conversion
  dist       - totally optional, so may not exist, default is NONE, ditribution
  nfb        - totally optional, so may not exist, default is 1 (NA for missing), no feel back
  cutoff     - totally optional, so may not exist, fsdlib->topholdings gives the number to cutoff
  matchDate  - totally optional, default is OFF, if ON then no feel back to holidays
  function   - function for extractecondata
  dbsource   - database source, for extractecondata
  dbug       - flag to get more debug info in the SAS log about the macro
               variables and their values. Uses PROC Printto to redirect the log
               information just like makefile.sas macro in dvtest/testauto does.
  proxy      - use a proxy server at this address
  connect    - Yes or No to connect through firewall on PROXY, s1148719, hot fix.
---------------------------------------------------------------*/
%macro fsd_filetransurl( fact=,form=,tick=,itms=,range=,universe=,
                         meta=,user=,pass=,universegroup=,
                         freq=,start=,end=,FQLfreq=,flag=,
                         ison=,isonParams=,ofdb=,cal=,datesOnly=,
                         screen=,name=,FQLflag=,dbug=,curr=0,matchDate=OFF,
                         conv=NONE,dist=NONE,nfb=1,cutoff=0,debug=,function=,dbsource=,
                         proxy=,proxyflag=0,connect=OFF );

    /*--- preset status to bad for early returns ---*/
    %let fsd_macro_status=1;
    %let nomydates = OFF;

    %let debug = &dbug;
 
    %if &debug=ON %then %do;
       options mprint symbolgen mlogic;
    %end;
    %else %do;
       options nonotes;

       %filename(newlog,newlog,tmp);

       proc printto log=newlog new;
       run;
       options notes;
    %end;

    %let zero = %str(0);
    %let connflag=&connect;
    %let globproxy=OFF;

    %if &connflag=ON %then %do;
        %let myconnect = %str(connect);
    %end;
        
    %if &proxyflag EQ &zero %then %do;
       %let proxy_len=0;
    %end;
    %else %do;
        %let proxy_len = %eval( %length(&proxy) );
        %let myproxy = %str(proxy=);
        
        %if &proxy_len > 2 %then %let globproxy = ON;
        
        %else %let proxy_len = 0;
    %end;

    options validvarname=any;
    %let mymeta = %nrstr(&orientation=);
    %let mypass = %str(pass=);
    %let myuser = %str(user=);
    %let myfact = %str(factlet=);
    %let myform = %nrstr(&format=);
    %let mytick = %nrstr(&ids=);
    %let myitms = %nrstr(&items=);
    %let mydates =%nrstr(&dates=);
    %let myfreq = %nrstr(&period=);
    %let myconv = %nrstr(&conv=);
    %let mydist = %nrstr(&dist=);
    %let mynfb = %nrstr(&nfb=);
    %let mycutoff = %nrstr(&cutoff=);
    %let mymatchDate = %nrstr(&matchDate=);

    %let myfunc = %nrstr(&function=);
    %let mydbsrc = %nrstr(&dbsource=);

    %let mycurr = %nrstr(&currency=);
    %let myFQLflag = %nrstr(&FQLflag=);
    %let myFQLfreq = %nrstr(&freq=);

    %let myison = %nrstr(&ison=); 
    %let myisonParams = %nrstr(&isonParams=);
    %let myuniverse = %nrstr(&universe=);
    %let myunigroup = %nrstr(&universegroup=);

    %let myofdb= %nrstr(&ofdb=);
    %let mycal=  %nrstr(&cal=);
    %let mydatesOnly= %nrstr(&datesOnly=);
    %let myscreen= %nrstr(&screen=);
    %let myname=  %nrstr(&name=);

    %let myurl = %str(https://datadirect.factset.com/services/FastFetch?);

    %if &tick EQ %then %do;
        %let ticklen=0;
    %end;
    %else %do;
        %let ticklen=%eval( %length(&tick)-2 );
    %end;

    %let nrbtick = %str(&tick);

    %let nrbitms = %str(&itms);

    %let nrbmeta = %str(&meta);
    %let nrbpass = %str(&pass); 
    %let nrbuser = %str(&user);
    %let nrbfact = %str(&fact);
    %let nrbform = %str(&form);    
    %let nrbrng = %str(&range);
    %let nrbfreq = %str(&freq);
    %let nrbconv = %str(&conv);
    %let nrbconvflag = %substr(&conv, 1, 1);
    %if &nrbconvflag EQ %str(N) %then %do;
        %let convlen= 0;
    %end;
    %else %let convlen = %length(&conv);

    %let nrbdist = %str(&dist);
    %let nrbdistflag = %substr(&dist, 1, 1);
    %if &nrbdistflag EQ %str(N) %then %do;
        %let distlen= 0;
    %end;
    %else %let distlen = %length(&dist);

    %let nrbFQLfreq = %str(&FQLfreq);

    %let nrbFQLflag = %substr(&FQLflag, 1, 1);
    %if &nrbFQLflag EQ %str(N) %then %do;
        %let FQLflaglen= 0;
    %end;
    %else %do;
        %let nrbFQLflag = %str(Y);
        %let FQLflaglen= 1;
    %end;

    %let nrbofdb = %str(&ofdb);

    %let nrbdOnly = %substr(&datesOnly, 1, 1);
    %if &nrbdOnly EQ %str(Y) %then %do;
        %let datesOnlylen= 1;
    %end;
    %else %do;
        %let nrbdOnly = %str(N);
        %let datesOnlylen= 0;
    %end; 

    %let nrbcal = %str(&cal);
    %let callen = %length(&cal);

    %let nrbison = %str(&ison);
    %let nrbisonParams = %str(&isonParams);
    
    %let nrbscreen = %str(&screen);
    %let nrbname = %str(&name);

    %let nrbcurr = %str(&curr);
    %let nrbnfb = %str(&nfb);
    %let nrbcutoff = %str(&cutoff);
    %let nrbmatchDate = %str(&matchDate);

    %let nrbfunc = %str(&function);
    %let nrbdbsrc = %str(&dbsource);

    %let nrbflag = %str(&flag);

    
    %if &nrbcurr EQ &zero %then %do;
        %let currlen=0;
    %end;
    %else %do;
        %let currlen=3;
    %end;

    %if &nrbcutoff EQ &zero %then %do;
        %let cutofflen=0;
    %end;
    %else %do;
        %let cutofflen=1;
    %end;

    %let one = %str(1);
    %if &nrbnfb EQ &one %then %do;
        %let nfblen=0;
    %end;
    %else %do;
        %let nfblen=1;
    %end;

    %if &nrbfunc EQ %then %do;
        %let funclen=0;
    %end;
    %else %do;
        %let funclen=%eval( %length(&function) );
    %end;

    %if &nrbdbsrc EQ %then %do;
        %let dbsrclen=0;
    %end;
    %else %do;
        %let dbsrclen=%eval( %length(&dbsource) );
    %end;

 /*--- extractdatasnapshot uses universegroup= but does not use ofdb= -----------*/
    %let unigrplen = %eval( %length(&universegroup) ); 
    %if &unigrplen <=0 %then %goto skipunigrp;  
    %let nrbunigroup = %str(&universegroup);

   %skipunigrp:                        
    %let unilen = %eval( %length(&universe) ); 
    %if &unilen <=0 %then %goto skip0;  
    %let nrbuniverse = %str(&universe);

   %skip0:                        
 /*--- remove the leading and trailing quotes from the ticker list (&ids=) ---*/
    %let len = %eval( %length(&tick)-2 );
    %if &len <=0 %then %goto skip1;      
    %let nrbtick = %substr( &tick, 2 , &len );

   %skip1:
 /*--- remove the leading and trailing quotes from the itms list (&items=) ---*/
    %let len = %eval( %length(&itms)-2 );
    %if &len <=0 %then %goto skip2;   
    %let nrbitms = %substr( &itms, 2 , &len );

   %skip2:
 /*--- remove the leading and trailing quotes from the range datelist (&dates=) ---*/
    %let rnglen = %eval( %length(&range)-2 );
    %if &rnglen <=0 %then %goto skip3;   
    %let nrbrng = %substr( &range, 2 , &rnglen );

   %skip3:
 /*--- remove the leading and trailing quotes from the ison isonlist (&ison=) ---*/
    %let isonlen = %eval( %length(&ison)-2 );
    %if &isonlen <=0 %then %goto skip4;  
    %let nrbison = %substr( &ison, 2 , &isonlen );

   %skip4:
 /*--- remove the leading and trailing quotes from the isonParams list (&isonParams=) ---*/
    %let iPlen = %eval( %length(&isonParams)-2 );   
    %if &iPlen <=0 %then %goto skip5;
    %let nrbisonParams = %substr( &isonParams, 2 , &iPlen );

   %skip5:
 /*--- remove the leading and trailing quotes from the freq since it could have hyphen for semi-ann ---*/
    %let freqlen = %length(&freq); 
    %let FQLfreqlen = %length(&FQLfreq); 
  
    %let ofdblen = %eval( %length(&ofdb)-2 );
    %if &ofdblen <=0 %then %goto skip6;
    %let nrbofdb = %substr( &ofdb, 2 , &ofdblen );

   %skip6:
 /*--- remove the leading and trailing quotes from the screen (&screen=) ---*/
    %let screenlen = %eval( %length(&screen)-2 );
    %if &screenlen <=0 %then %goto skip7;
    %let nrbscreen = %substr( &screen, 2 , &screenlen );

    /*--- name should by Y for YES or N for NO --------------------------------*/
    %let namelen = %eval( %length(&name);
    %if &namelen > 0 %then %do;
    /*--- name should by Y for YES or N for NO --------------------------------*/
        %let namelen = 1;
        %let nrbname = %substr( &name, 1 , &namelen );
    %end;
    %else %do;
        %let nrbname = %str(N); 
        %let namelen = 1;
    %end;

    %goto screenUni;   /*--- ExtractScreenUniverse does its own thing ---------*/
 
   %skip7:
 /*--- if no datestring for a range datelist, then check for the start=, end= ---*/
    %if &rnglen=0 %then %do;
        /*--- these two are simple numerics, convert to strings -----------------*/
        %let nrbstart = %str(&start);
        %let nrbend = %str(&end);

        %let mystart = %nrstr(&start=); 
        %let myend = %nrstr(&end=);
 
        %if &nrbfact = %str(EXTRACTECONDATA) %then %goto econdata_check;
        %let mydates=&mystart.&nrbstart;
        %let nrbrng=&myend.&nrbend;
        %goto next_check;

   %econdata_check:
        %if &nrbstart EQ &zero %then %do; 
            %if &nrbend EQ &zero %then %do;
               %let nomydates = ON;
            %end;
        %end;
        %else %do;
           %let mydates=&mystart.&nrbstart;
           %let nrbrng=&myend.&nrbend;
           %let nomydates = OFF;
        %end;
    %end;

   %next_check:
 /*--------------------------------------------------------*/
 /*--- Validation of parameters supplied to macro       ---*/
 /*--------------------------------------------------------*/  
    %if &nrbpass EQ %then %do;
        %put ERROR: PASS= parameter required for FSD_FILETRANSURL macro.;
        %goto exit;
    %end;
    %if &nrbuser EQ %then %do;
        %put ERROR: USER= parameter required for FSD_FILETRANSURL macro.;
        %goto exit;
    %end;

    %if &nrbfact = %str(EXTRACTECONDATA) %then %goto EconData;

 /*--------------------------------------------------------*/
 /*--- Build FILENAME statement with URL for FactSet    ---*/
 /*--------------------------------------------------------*/
    %if &nrbfact= %then %do;

        filename trans url
   'https://datadirect.factset.com/services/FastFetch?factlet=extractcompanydata&format=sml&ids=ibm,fds,goog&items=p_price,p_volume&dates=20100615:20110315:m&orientation=eti'                
        &myuser.&nrbuser
        &mypass.&nrbpass;
    
    %end;
    %else %do;    
        %if &isonlen<=0 %then %do;
           %if &ofdblen<=0 %then %do;
               %if unigrplen<=0 %then %do;
                   %if &callen<=0 %then %do;  /* most often occurrence, no cal, no ison, no ofdb */
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                               %if &unilen <=0 %then %do;
                                   %if &cutofflen <= 0 %then %do;
                                      %if &matchDate=ON %then %do;
                                         %if &globproxy=OFF %then %do; 
                                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                            filename trans url "&glob"
                                            &myuser.&nrbuser
                                            &mypass.&nrbpass
                                            &myconnect;
                                         %end;
                                         %else %do;  /* PROXY= option */
                                            %if &connect=ON %then %do; 
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy"
                                               connect;
                                            %end;
                                            %else %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy";
                                            %end;
                                         %end;   
                                      %end;
                                      %else %do;
                                         %if &globproxy=OFF %then %do; 
                                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                            filename trans url "&glob"
                                            &myuser.&nrbuser
                                            &mypass.&nrbpass
                                            &myconnect;
                                         %end;
                                         %else %do;  /* PROXY= option */
                                            %if &connect=ON %then %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy"
                                               connect;
                                            %end;
                                            %else %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy";
                                            %end;
                                         %end;
                                      %end;
                                   %end; /* added on debugging!!! */
                                   %else %do; /* add cutoff= to the request */
                                      %if &matchDate=ON %then %do;
                                         %if &globproxy=OFF %then %do; 
                                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                            filename trans url "&glob"
                                            &myuser.&nrbuser
                                            &mypass.&nrbpass
                                            &myconnect;
                                         %end;
                                         %else %do; /* PROXY= option */
                                            %if &connect=ON %then %do; 
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy"
                                               connect;
                                            %end;
                                            %else %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy";
                                            %end;
                                         %end;
                                      %end;
                                      %else %do;
                                         %if &globproxy=OFF %then %do;
                                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                            filename trans url "&glob"
                                            &myuser.&nrbuser
                                            &mypass.&nrbpass
                                            &myconnect;
                                         %end;
                                         %else %do; /* PROXY= option */
                                            %if &connect=ON %then %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy"
                                               connect;
                                            %end;
                                            %else %do;
                                               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                               filename trans url "&glob"
                                               &myuser.&nrbuser
                                               &mypass.&nrbpass
                                               &myproxy "&proxy";
                                            %end;
                                         %end;
                                      %end;
                                   %end;
                               %end; /* end no universe */
                               %else %do; /* universe for ExtractCompanyData, instead of ticker list(ids=) */
                                  %if &globproxy=OFF %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myconnect;
                                  %end;
                                  %else %do; /* PROXY= option */
                                     %if &connect=ON %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myproxy "&proxy"
                                        connect;
                                     %end;
                                     %else %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myproxy "&proxy";
                                     %end;
                                  %end;                                  
                               %end; /* end universe */
                           %end; /* end no currency */
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end; /* end if no FQLfreq */
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                               %if &cutofflen <= 0 %then %do;
                                  %if &matchDate=ON %then %do;
                                     %if &globproxy=OFF %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                                  %else %do;
                                     %if &globproxy=OFF %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                               %end;
                               %else %do; /* add cutoff= to the request */
                                  %if &matchDate=ON %then %do;
                                     %if &globproxy=OFF %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                                  %else %do;
                                     %if &globproxy=OFF %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                               %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end; /* end FQLfreq */
                   %end; /* end no CAL */
                   %else %do; /* CAL */
                       %if &currlen<=0 %then %do;
                           %if &globproxy=OFF %then %do;
                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal;
                              filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                           %end;
                           %else %do; /* PROXY= option */
                              %if &connect=ON %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal;
                                 filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                              %end;
                              %else %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal;
                                 filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                              %end;
                           %end;
                       %end;
                       %else %do; /* Currency */
                           %if &globproxy=OFF %then %do;
                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr;
                              filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                           %end;
                           %else %do; /* PROXY= option */
                              %if &connect=ON %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                              %end;
                              %else %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                              %end;
                           %end;
                       %end;
                   %end; /* end CAL */
               %end; /* end no UNIVERSEGROUP= */
               %else %do; /* UNIVERSEGROUP= */
                   %if &callen<=0 %then %do;  /* most often occurrence, no cal, no ison, no ofdb */
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                               %if &unilen <=0 %then %do;
                                  %if &cutofflen <= 0 %then %do;
                                     %if &matchDate=ON %then %do;
                                        %if &globproxy=OFF %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myconnect;
                                        %end;
                                        %else %do; /* PROXY= option */
                                           %if &connect=ON %then %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy"
                                              connect;
                                           %end;
                                           %else %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy";
                                           %end;
                                        %end;
                                     %end;
                                     %else %do;
                                        %if &globproxy=OFF %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myconnect;
                                        %end;
                                        %else %do; /* PROXY= option */
                                           %if &connect=ON %then %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy"
                                              connect;
                                           %end;
                                           %else %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy";
                                           %end;
                                        %end;
                                     %end;
                                  %end;
                                  %else %do; /* add cutoff= to the request */
                                     %if &matchDate=ON %then %do;
                                        %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myconnect;
                                        %end;
                                        %else %do; /* PROXY= option */
                                           %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;

                                             filename trans url "&glob"
                                             &myuser.&nrbuser
                                             &mypass.&nrbpass
                                             &myproxy "&proxy"
                                             connect;
                                           %end;
                                           %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;

                                             filename trans url "&glob"
                                             &myuser.&nrbuser
                                             &mypass.&nrbpass
                                             &myproxy "&proxy";
                                           %end;
                                        %end;
                                     %end;
                                     %else %do;
                                        %if &globproxy=OFF %then %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myconnect;
                                        %end;
                                        %else %do; /* PROXY= option */
                                           %if &connect=ON %then %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy"
                                              connect;
                                           %end;
                                           %else %do;
                                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                              filename trans url "&glob"
                                              &myuser.&nrbuser
                                              &mypass.&nrbpass
                                              &myproxy "&proxy";
                                           %end;
                                        %end;
                                     %end; 
                                  %end;
                               %end; /* end no universe */
                               %else %do; /* universe for ExtractCompanyData, instead of ticker list(ids=) */
                                  %if &globproxy=OFF %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myconnect;
                                  %end;
                                  %else %do; /* PROXY= option */
                                     %if &connect=ON %then %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myproxy "&proxy"
                                        connect;
                                     %end;
                                     %else %do;
                                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myuniverse.&nrbuniverse.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myproxy "&proxy";
                                     %end;
                                  %end;
                               %end; /* end universe */
                           %end; /* end no currency */
                           %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                 %end;
                                 %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                       %end; /* end if no FQLfreq */
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                               %if &cutofflen <= 0 %then %do;
                                  %if &matchDate=ON %then %do;
                                     %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;

                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;

                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                                  %else %do;
                                     %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
                                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                               %end;
                               %else %do; /* add cutoff= to the request */
                                  %if &matchDate=ON %then %do;
                                     %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;

                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;   

                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup.&mymatchDate.&nrbmatchDate;   

                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                                  %else %do;
                                     %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                        filename trans url "&glob"
                                        &myuser.&nrbuser
                                        &mypass.&nrbpass
                                        &myconnect;
                                     %end;
                                     %else %do; /* PROXY= option */
                                        %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy"
                                           connect;
                                        %end;
                                        %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycutoff.&nrbcutoff.&myunigroup.&nrbunigroup;
                                           filename trans url "&glob"
                                           &myuser.&nrbuser
                                           &mypass.&nrbpass
                                           &myproxy "&proxy";
                                        %end;
                                     %end;
                                  %end;
                               %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end; /* end FQLfreq */
                   %end; /* end no CAL */
                   %else %do; /* CAL */
                       %if &currlen<=0 %then %do;
                           %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&myunigroup.&nrbunigroup;
                              filename trans url "&glob"
                              &myuser.&nrbuser
                              &mypass.&nrbpass
                              &myconnect;
                           %end;
                           %else %do; /* PROXY= option */
                              %if &connect=ON %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myproxy "&proxy"
                                 connect;
                              %end;
                              %else %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myproxy "&proxy";
                              %end;
                           %end;
                       %end;
                       %else %do; /* Currency */
                           %if &globproxy=OFF %then %do;
                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                              filename trans url "&glob"
                              &myuser.&nrbuser
                              &mypass.&nrbpass
                              &myconnect;
                           %end;
                           %else %do; /* PROXY= option */
                              %if &connect=ON %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myproxy "&proxy"
                                 connect;
                              %end;
                              %else %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mycal.&nrbcal.&mycurr.&nrbcurr.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myproxy "&proxy";
                              %end;
                           %end;
                       %end;
                   %end; /* end CAL */
               %end; /* end UNIVERSEGROUP------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ */
           %end;
           %else %do; /* OFDB and NO CAL? */
               %if &datesOnlylen>0 %then %do;
                  %if &globproxy=OFF %then %do;
                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                     filename trans url "&glob"
                     &myuser.&nrbuser
                     &mypass.&nrbpass
                     &myconnect;
                     %goto exit;
                  %end;
                  %else %do; /* PROXY= option */
                     %if &connect=ON %then %do;
                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                        filename trans url "&glob"
                        &myuser.&nrbuser
                        &mypass.&nrbpass
                        &myproxy "&proxy"
                        connect;
                        %goto exit;
                     %end;
                     %else %do;
                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                        filename trans url "&glob"
                        &myuser.&nrbuser
                        &mypass.&nrbpass
                        &myproxy "&proxy"
                        %goto exit;
                     %end;
                  %end;
               %end;
               %if &ticklen<=0 %then %do;  /* NULL ids= option */
                 %if &FQLflaglen<=0 %then %do; 
                    %if &currlen<=0 %then %do;
                       %if &globproxy=OFF %then %do;
                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                           filename trans url "&glob"
                           &myuser.&nrbuser
                           &mypass.&nrbpass
                           &myconnect;
                       %end;
                       %else %do; /* PROXY= option */
                          %if &connect=ON %then %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy"
                             connect;
                          %end;
                          %else %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy";
                          %end;
                       %end;
                    %end;
                    %else %do; /* Currency */
                       %if &globproxy=OFF %then %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myconnect;
                       %end;
                       %else %do; /* PROXY= option */
                          %if &connect=ON %then %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass;
                             &myproxy "&proxy"
                             connect;
                          %end;
                          %else %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass;
                             &myproxy "&proxy";
                          %end;
                       %end;
                    %end;
                 %end; /* end FQLflaglen=0 */
                 %else %do; /* FQLflag = Y */
                    %if &currlen<=0 %then %do;
                       %if &globproxy=OFF %then %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myconnect;
                       %end;
                       %else %do; /* PROXY= option */
                          %if &connect=ON %then %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy"
                             connect;
                          %end;
                          %else %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy";
                          %end;
                       %end;
                    %end;
                    %else %do; /* Currency */
                        %if &globproxy=OFF %then %do;
                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                           filename trans url "&glob"
                           &myuser.&nrbuser
                           &mypass.&nrbpass
                           &myconnect;
                        %end;
                       %else %do; /* PROXY= option */
                          %if &connect=ON %then %do;
                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                              filename trans url "&glob"
                              &myuser.&nrbuser
                              &mypass.&nrbpass
                              &myproxy "&proxy"
                              connect;
                          %end;
                          %else %do;
                              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                              filename trans url "&glob"
                              &myuser.&nrbuser
                              &mypass.&nrbpass
                              &myproxy "&proxy";
                          %end;
                       %end;
                    %end;
                 %end; /* end else FQLflag=Y */                 
                 %goto exit;
               %end; /* end ticklen<=0, no ids= option */

               %if &FQLflaglen<=0 %then %do; 
                  %if &currlen<=0 %then %do;
                     %if &globproxy=OFF %then %do;
                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                        filename trans url "&glob"
                        &myuser.&nrbuser
                        &mypass.&nrbpass
                        &myconnect;
                    %end;
                    %else %do; /* PROXY= option */
                       %if &connect=ON %then %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myproxy "&proxy"
                          connect;
                       %end;
                       %else %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myproxy "&proxy";
                       %end;
                    %end;
                  %end;
                  %else %do; /* Currency */
                      %if &globproxy=OFF %then %do;
                         %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                         filename trans url "&glob"
                         &myuser.&nrbuser
                         &mypass.&nrbpass
                         &myconnect;
                      %end;
                      %else %do; /* PROXY= option */
                         %if &connect=ON %then %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy"
                            connect;
                         %end;
                         %else %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy";
                         %end;
                      %end;
                  %end;
               %end; /* end FQLflaglen=0 */
               %else %do; /* FQLflag = Y */
                  %if &currlen<=0 %then %do;
                     %if &globproxy=OFF %then %do;
                        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                        filename trans url "&glob"
                        &myuser.&nrbuser
                        &mypass.&nrbpass
                        &myconnect;
                     %end;
                     %else %do; /* PROXY= option */
                        %if &connect=ON %then %do;
                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                           filename trans url "&glob"
                           &myuser.&nrbuser
                           &mypass.&nrbpass
                           &myproxy "&proxy"
                           connect;
                        %end;
                        %else %do;
                           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                           filename trans url "&glob"
                           &myuser.&nrbuser
                           &mypass.&nrbpass
                           &myproxy "&proxy";
                        %end;
                     %end;
                  %end;
                  %else %do; /* Currency */
                      %if &globproxy=OFF %then %do;
                         %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                         filename trans url "&glob"
                         &myuser.&nrbuser
                         &mypass.&nrbpass
                         &myconnect;
                      %end;
                      %else %do; /* PROXY= option */
                         %if &connect=ON %then %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy"
                            connect;
                         %end;
                         %else %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy";
                         %end;   
                      %end;
                  %end;
               %end; /* end else FQLflag=Y */
           %end; /* end else OFDB and NO CAL? */
        %end; /* end NO ISON */
        %else %do; /* ISON */
            %if &iPlen<=0 %then %do;
                %if &ofdblen<=0 %then %do; /* NO OFDB= */
                   %if unigrplen<=0 %then %do;
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end;
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                       %end; /* end FQLfreq */
                   %end; /* end no UNIVERSEGROUP= */
                   %else %do; /* UNIVERSEGROUP= */
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end;
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end; /* end FQLfreq */
                   %end;      /* UNIVERSEGROUP= --------------------------------------------------------------------------------------------------------------------------------------------------------------------*/
                %end; /* end of NO OFDB */
                %else %do; /* OFDB */
                    %if &datesOnlylen>0 %then %do;
                       %if &globproxy=OFF %then %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myconnect;
                          %goto exit;
                       %end;
                       %else %do; /* PROXY= option */
                          %if &connect=ON %then %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy"
                             connect;
                             %goto exit;

                          %end;
                          %else %do;
                             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                             filename trans url "&glob"
                             &myuser.&nrbuser
                             &mypass.&nrbpass
                             &myproxy "&proxy";
                             %goto exit;
                          %end;
                       %end;
                    %end;

                    %if &FQLflaglen<=0 %then %do; 
                       %if &FQLfreqlen<=0 %then %do;
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end;
                       %else %do; /* FQLfreq */
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end; /* end else FQLfreq */
                    %end; /* end no FQLflag */
                    %else %do; /* FQLflag */
                       %if &FQLfreqlen<=0 %then %do;
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end;
                       %else %do; /* FQLfreq */
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end; /* end else FQLfreq */
                    %end; /* end FQLflag */
                %end; /* end OFDB */
            %end; /* end ISON, no params */
            %else %do; /* ISONPARAMS */
                %if &ofdblen<=0 %then %do; /* no OFDB */
                    %if unigrplen<=0 %then %do;
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end;
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end; /* FQLfreq */
                    %end; /* end no UNIVERSEGROUP= */
                    %else %do; /* UNIVERSEGROUP= */
                       %if &FQLfreqlen<=0 %then %do;
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                               %if &globproxy=OFF %then %do;
                                  %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                  filename trans url "&glob"
                                  &myuser.&nrbuser
                                  &mypass.&nrbpass
                                  &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
                                     %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                           %end;
                       %end;
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                           %end;
                           %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myunigroup.&nrbunigroup.&mycurr.&nrbcurr;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                 %end;
                              %end; 
                           %end;
                       %end; /* FQLfreq */
                    %end; /* end UNIVERSEGROUP= ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------*/
                %end; /* end NO OFDB */
                %else %do; /* OFDB */
                    %if &datesOnlylen>0 %then %do;
                       %if &globproxy=OFF %then %do;
                          %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                          filename trans url "&glob"
                          &myuser.&nrbuser
                          &mypass.&nrbpass
                          &myconnect;
                          %goto exit;
                       %end;
                       %else %do; /* PROXY= option */
                         %if &connect=ON %then %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy"
                            connect;
                            %goto exit;
                         %end;
                         %else %do;
                            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mydatesOnly.&nrbdOnly.&mymeta.&nrbmeta.&myofdb.&nrbofdb;
                            filename trans url "&glob"
                            &myuser.&nrbuser
                            &mypass.&nrbpass
                            &myproxy "&proxy";
                            %goto exit;
                         %end;
                       %end;
                    %end;
                    %if &FQLflaglen<=0 %then %do; 
                       %if &FQLfreqlen<=0 %then %do;
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;              
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end; /* end no FQLfreq */
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do; 
                              %if &globproxy=OFF %then %do;
                                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
                                    %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";

                                 %end;
                              %end;
                          %end;
                       %end; /* end else FQLfreq */
                   %end; /* end no FQLflag */
                   %else %do; /* FQLflag */
                       %if &FQLfreqlen<=0 %then %do;
                          %if &currlen<=0 %then %do;
                             %if &globproxy=OFF %then %do;
                                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                filename trans url "&glob"
                                &myuser.&nrbuser
                                &mypass.&nrbpass
                                &myconnect;
                             %end;
                             %else %do; /* PROXY= option */
                                %if &connect=ON %then %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy"
                                   connect;
                                %end;
                                %else %do;
                                   %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                   filename trans url "&glob"
                                   &myuser.&nrbuser
                                   &mypass.&nrbpass
                                   &myproxy "&proxy";
                                %end;
                             %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                               %end;
                               %else %do; /* PROXY= option */
                                  %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy"
                                     connect;
                                  %end;
                                  %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&mycurr.&nrbcurr.&myFQLflag.&nrbFQLflag;
                                     filename trans url "&glob"
                                     &myuser.&nrbuser
                                     &mypass.&nrbpass
                                     &myproxy "&proxy";
                                  %end;
                               %end;
                          %end;
                       %end; /* end no FQLfreq */
                       %else %do; /* FQLfreq */
                           %if &currlen<=0 %then %do;
                              %if &globproxy=OFF %then %do;
                              %let glob =
                               &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;

                              %let glob =
                               &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;

                              %let glob =
                               &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                          %else %do; /* Currency */
                              %if &globproxy=OFF %then %do;
              %let glob =
                 &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                                 filename trans url "&glob"
                                 &myuser.&nrbuser
                                 &mypass.&nrbpass
                                 &myconnect;
                              %end;
                              %else %do; /* PROXY= option */
                                 %if &connect=ON %then %do;
              %let glob =
                 &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy"
                                    connect;
                                 %end;
                                 %else %do;
              %let glob =
                 &myurl.&myfact.&nrbfact.&myform.&nrbform.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myFQLfreq.&nrbFQLfreq.&mymeta.&nrbmeta.&myison.&nrbison.&myisonParams.&nrbisonParams.&myofdb.&nrbofdb.&myFQLflag.&nrbFQLflag.&mycurr.&nrbcurr;
                                    filename trans url "&glob"
                                    &myuser.&nrbuser
                                    &mypass.&nrbpass
                                    &myproxy "&proxy";
                                 %end;
                              %end;
                          %end;
                       %end; /* end else FQLfreq */
                   %end; /* end FQLflag */
                %end; /* OFDB */
            %end;  /* ISONPARAMS  */   
        %end; /* ISON */
    %end; /* FACTLET */
   %goto exit;

   /*---- ExtractScreenUniverse ----------------------------------------------------------------*/
   %screenUni:
   /*--------------------------------------------------------*/
   /*--- Validation of parameters supplied to macro       ---*/
   /*--------------------------------------------------------*/  
     %if &nrbpass EQ %then %do;
         %put ERROR: PASS= parameter required for FSD_FILETRANSURL macro.;
         %goto exit;
     %end;
     %if &nrbuser EQ %then %do;
         %put ERROR: USER= parameter required for FSD_FILETRANSURL macro.;
         %goto exit;
     %end;

     %if &namelen=1 %then %do;
        %if &globproxy=OFF %then %do;
           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myscreen.&nrbscreen.&myname.&nrbname.&mymeta.&nrbmeta;
           filename trans url "&glob"              
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
        %end;
        %else %do; /* PROXY= option */
           %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myscreen.&nrbscreen.&myname.&nrbname.&mymeta.&nrbmeta;
              filename trans url "&glob"              
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
           %end;
           %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&myscreen.&nrbscreen.&myname.&nrbname.&mymeta.&nrbmeta;
              filename trans url "&glob"              
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
           %end;
        %end;
     %end;
     %else %do;
        %put ERROR: Invalid parameter for Factlet=ExtractScreenUniverse in FSD_FILETRANSURL macro.;
        %goto exit;
     %end;
   %goto exit;  /* end of ExtractScreenUniverse */

   %EconData:
    %if &funclen>0 %then %goto FunData;
     %if &nomydates=ON %then %goto EconNoDates;

     %if &nfblen<=0 %then %do;
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* none for all */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
              %if &connect=ON %then %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy"
                 connect;
              %end;
              %else %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy";
              %end;
          %end;
       %end;
       %else %do; /*distribution only*/
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
              %if &connect=ON %then %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy"
                 connect;
              %end;
              %else %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy";
              %end;
          %end;
       %end;
      %end;  /* we have conversion length */
      %else %do; /*conversion*/
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end;  /* we have no feel back */
     %else %do; /* YES FEEL BACK */
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* nfb only */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /* dist and nfb */
          %if &globproxy=OFF %then %do;
        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
        %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end; /* end of no convlen */
      %else %do; /* conversion and nfb, assume distribution too */
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end; /* end of nfb= */
    %goto exit; /*--- end of no function with start and end dates for extractecondata factlet -------------------------------------------------------------------------*/
   %EconNoDates: /*--- begin no function no dates for for extractecondata factlet ------------------------------------------------------------*/ 

     %if &nfblen<=0 %then %do;
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* none for all */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /*distribution only*/
           %if &globproxy=OFF %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
              filename trans url "&glob"
              &myuser.&nrbuser
              &mypass.&nrbpass
              &myconnect;
           %end;
           %else %do; /* PROXY= option */
              %if &connect=ON %then %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy"
                 connect;
              %end;
              %else %do;
                 %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                 filename trans url "&glob"
                 &myuser.&nrbuser
                 &mypass.&nrbpass
                 &myproxy "&proxy";
              %end;
           %end;
       %end;
      %end;  /* we have conversion length */
      %else %do; /*conversion*/
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end;  /* we have no feel back */
     %else %do; /* YES FEEL BACK */
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* nfb only */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /* dist and nfb */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end; /* end of no convlen */
      %else %do; /* conversion and nfb, assume distribution too */
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end; /* end of nfb= */
    %goto exit; /*--- end of no function with no start and no end dates for extractecondata factlet ------------------------------------------*/


   %FunData: /*--- begin of function for extractecondata factlet -----------------------------------------------------------------------------*/
    %if &nomydates=ON %then %goto FunDataNoDate;

    %if &nfblen<=0 %then %do;
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* none for all */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /*distribution only*/
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end;  /* we have conversion length */
      %else %do; /*conversion*/
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
             %end;
             %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
             %end;
         %end;
      %end;
     %end;  /* we have no feel back */
     %else %do; /* YES FEEL BACK */
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* nfb only */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /* dist and nfb */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end; /* end of no convlen */
      %else %do; /* conversion and nfb, assume distribution too */
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&mydates.&nrbrng.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end; /* end of nfb= */
    %goto exit; /*--- end of function for extractecondata factlet -------------------------------------------------------------------------*/

   %FunDataNoDate:
     %if &nfblen<=0 %then %do;
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* none for all */
        %if &globproxy=OFF %then %do;
           %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
           filename trans url "&glob"
           &myuser.&nrbuser
           &mypass.&nrbpass
           &myconnect;
        %end;              
        %else %do; /* PROXY= option */
           %if &connect=ON %then %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
              filename trans url "&glob"
              &myuser.&nrbuser
              &mypass.&nrbpass
              &myproxy "&proxy"
              connect;
           %end;
           %else %do;
              %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
              filename trans url "&glob"
              &myuser.&nrbuser
              &mypass.&nrbpass
              &myproxy "&proxy";
           %end; /* semicolon added during debugging */
        %end;
       %end;
       %else %do; /*distribution only*/
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end;  /* we have conversion length */
      %else %do; /*conversion*/ 
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end;  /* we have no feel back */
     %else %do; /* YES FEEL BACK */
      %if &convlen<=0 %then %do;
       %if &distlen<=0 %then %do; /* nfb only */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
       %else %do; /* dist and nfb */
          %if &globproxy=OFF %then %do;
             %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
             filename trans url "&glob"
             &myuser.&nrbuser
             &mypass.&nrbpass
             &myconnect;
          %end;
          %else %do; /* PROXY= option */
             %if &connect=ON %then %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy"
                connect;
             %end;
             %else %do;
                %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
                filename trans url "&glob"
                &myuser.&nrbuser
                &mypass.&nrbpass
                &myproxy "&proxy";
             %end;
          %end;
       %end;
      %end; /* end of no convlen */
      %else %do; /* conversion and nfb, assume distribution too */
         %if &globproxy=OFF %then %do;
            %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
            filename trans url "&glob"
            &myuser.&nrbuser
            &mypass.&nrbpass
            &myconnect;
         %end;
         %else %do; /* PROXY= option */
            %if &connect=ON %then %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy"
               connect;
            %end;
            %else %do;
               %let glob = &myurl.&myfact.&nrbfact.&myform.&nrbform.&mytick.&nrbtick.&myitms.&nrbitms.&myfreq.&nrbfreq.&myfunc.&nrbfunc.&myconv.&nrbconv.&mydist.&nrbdist.&mynfb.&nrbnfb.&mymeta.&nrbmeta.&mydbsrc.&nrbdbsrc;
               filename trans url "&glob"
               &myuser.&nrbuser
               &mypass.&nrbpass
               &myproxy "&proxy";
            %end;
         %end;
      %end;
     %end; /* end of nfb= */
    %goto exit; /*--- end of function no start or end dates for extractecondata factlet -------------------------------------------------------------------------*/

   %exit:
    *-- unconditionally cut notes on --;
    options nonotes;
    %if &debug=OFF %then %do;
       proc printto log=log;
       run;
       %ridfile(newlog.tmp);
    %end;

    options notes; options validvarname=any;

    %let fsd_macro_status=0;
%mend fsd_filetransurl;
